@@ -74,12 +74,8 @@ class Conda(QObject):
         if ok:
             if "actions" in resultDict and "PREFIX" in resultDict["actions"]:
                 prefix = resultDict["actions"]["PREFIX"]
-            elif "prefix" in resultDict:
-                prefix = resultDict["prefix"]
-            elif "dst_prefix" in resultDict:
-                prefix = resultDict["dst_prefix"]
             else:
-                prefix = ""
+                prefix = resultDict.get("prefix", resultDict.get("dst_prefix", ""))
 
             # determine Python executable
             if prefix:
