@@ -7,7 +7,6 @@
 Module implementing the Python3 debugger interface for the debug server.
 """
 
-import sys
 import os
 import logging
 import shlex
@@ -208,8 +207,9 @@ class DebuggerInterfacePython(QObject):
         else:
             debugClient = Preferences.getDebugger("DebugClient3")
             if debugClient == "":
+                # use the 'standard' debug client if no custom one was configured
                 debugClient = os.path.join(
-                    sys.path[0], "DebugClients", "Python", "DebugClient.py"
+                    getConfig("ericDir"), "DebugClients", "Python", "DebugClient.py"
                 )
 
         redirect = (
