@@ -544,14 +544,13 @@ class PackageDiagramBuilder(UMLDiagramBuilder):
         data = {
             "project_name": self.project.getProjectName(),
             "no_attributes": self.noAttrs,
+            "package": (
+                Utilities.fromNativeSeparators(self.__relPackage)
+                if self.__relPackage
+                else Utilities.fromNativeSeparators(self.package)
+            ),
         }
 
-        data["package"] = (
-            Utilities.fromNativeSeparators(self.__relPackage)
-            if self.__relPackage
-            else Utilities.fromNativeSeparators(self.package)
-        )
-
         return data
 
     def fromDict(self, version, data):
