@@ -911,7 +911,7 @@ class JediServer(EricJsonServer):
             clientEnv["PATH"] = self.__ui.getOriginalPathString()
 
         if projectLanguage in ("Python3", "MicroPython", "Cython"):
-            interpreter = self.__ericProject.getProjectInterpreter(resolveGlobal=False)
+            interpreter = self.__ericProject.getProjectInterpreter()
             if interpreter:
                 execPath = self.__ericProject.getProjectExecPath()
 
