@@ -224,10 +224,11 @@ def codeStyleBatchCheck(argumentsList, send, fx, cancelled, maxProcesses=0):
     taskQueue = multiprocessing.Queue()
     doneQueue = multiprocessing.Queue()
 
-    # Submit tasks (initially two time number of processes
-    initialTasks = 2 * NumberOfProcesses
-    for task in argumentsList[:initialTasks]:
-        taskQueue.put(task)
+    # Submit tasks (initially two times the number of processes)
+    tasks = len(argumentsList)
+    initialTasks = min(2 * NumberOfProcesses, tasks)
+    for _ in range(initialTasks):
+        taskQueue.put(argumentsList.pop(0))
 
     # Start worker processes
     workers = [
@@ -238,8 +239,7 @@ def codeStyleBatchCheck(argumentsList, send, fx, cancelled, maxProcesses=0):
         worker.start()
 
     # Get and send results
-    endIndex = len(argumentsList) - initialTasks
-    for i in range(len(argumentsList)):
+    for _ in range(tasks):
         resultSent = False
         wasCancelled = False
 
@@ -259,8 +259,8 @@ def codeStyleBatchCheck(argumentsList, send, fx, cancelled, maxProcesses=0):
             # just exit the loop ignoring the results of queued tasks
             break
 
-        if i < endIndex:
-            taskQueue.put(argumentsList[i + initialTasks])
+        if argumentsList:
+            taskQueue.put(argumentsList.pop(0))
 
     # Tell child processes to stop
     for _ in range(NumberOfProcesses):
@@ -270,6 +270,9 @@ def codeStyleBatchCheck(argumentsList, send, fx, cancelled, maxProcesses=0):
         worker.join()
         worker.close()
 
+    taskQueue.close()
+    doneQueue.close()
+
 
 def workerTask(inputQueue, outputQueue):
     """
