@@ -169,8 +169,6 @@ class CodeStyleCheckerDialog(QDialog, Ui_CodeStyleCheckerDialog):
         self.fixButton.setEnabled(False)
 
         self.checkProgress.setVisible(False)
-        self.checkProgressLabel.setVisible(False)
-        self.checkProgressLabel.setMaximumWidth(600)
 
         self.styleCheckService = styleCheckService
         self.styleCheckService.styleChecked.connect(self.__processResult)
@@ -694,7 +692,6 @@ class CodeStyleCheckerDialog(QDialog, Ui_CodeStyleCheckerDialog):
         self.progressList.clear()
         if len(self.files) > 0:
             self.checkProgress.setMaximum(len(self.files))
-            self.checkProgressLabel.setVisible(len(self.files) > 1)
             self.checkProgress.setVisible(len(self.files) > 1)
             if len(self.files) > 1:
                 if self.__project:
@@ -933,7 +930,6 @@ class CodeStyleCheckerDialog(QDialog, Ui_CodeStyleCheckerDialog):
         @type str
         """
         if not self.files:
-            self.checkProgressLabel.setPath("")
             self.checkProgress.setMaximum(1)
             self.checkProgress.setValue(1)
             self.__finish()
@@ -941,7 +937,6 @@ class CodeStyleCheckerDialog(QDialog, Ui_CodeStyleCheckerDialog):
 
         self.filename = self.files.pop(0)
         self.checkProgress.setValue(self.progress)
-        self.checkProgressLabel.setPath(self.filename)
         QApplication.processEvents()
 
         if self.cancelled:
@@ -993,8 +988,6 @@ class CodeStyleCheckerDialog(QDialog, Ui_CodeStyleCheckerDialog):
         """
         self.__lastFileItem = None
 
-        self.checkProgressLabel.setPath(self.tr("Preparing files..."))
-
         argumentsList = []
         for progress, filename in enumerate(self.files, start=1):
             self.checkProgress.setValue(progress)
@@ -1032,7 +1025,6 @@ class CodeStyleCheckerDialog(QDialog, Ui_CodeStyleCheckerDialog):
 
         # reset the progress bar to the checked files
         self.checkProgress.setValue(self.progress)
-        self.checkProgressLabel.setPath(self.tr("Transferring data..."))
         QApplication.processEvents()
 
         self.__finished = False
@@ -1042,7 +1034,6 @@ class CodeStyleCheckerDialog(QDialog, Ui_CodeStyleCheckerDialog):
         """
         Private slot handling the completion of a batch job.
         """
-        self.checkProgressLabel.setPath("")
         self.checkProgress.setMaximum(1)
         self.checkProgress.setValue(1)
         self.__finish()
@@ -1137,7 +1128,6 @@ class CodeStyleCheckerDialog(QDialog, Ui_CodeStyleCheckerDialog):
             fn = os.path.join("...", self.__project.getRelativePath(fn))
 
         self.checkProgress.setValue(self.progress)
-        self.checkProgressLabel.setPath(fn)
 
         # remove file from the list of jobs to do
         fileItems = self.progressList.findItems(fn, Qt.MatchFlag.MatchExactly)
@@ -1193,7 +1183,6 @@ class CodeStyleCheckerDialog(QDialog, Ui_CodeStyleCheckerDialog):
                 self.filterButton.setEnabled(True)
 
             self.checkProgress.setVisible(False)
-            self.checkProgressLabel.setVisible(False)
 
             self.__resort()
             self.resultList.setUpdatesEnabled(True)
