@@ -74,8 +74,6 @@ class SyntaxCheckerDialog(QDialog, Ui_SyntaxCheckerDialog):
         self.filterFrame.setVisible(False)
 
         self.checkProgress.setVisible(False)
-        self.checkProgressLabel.setVisible(False)
-        self.checkProgressLabel.setMaximumWidth(600)
 
         try:
             self.syntaxCheckService = ericApp().getObject("SyntaxCheckService")
@@ -220,7 +218,6 @@ class SyntaxCheckerDialog(QDialog, Ui_SyntaxCheckerDialog):
             if codestring or len(self.files) > 0:
                 self.checkProgress.setMaximum(max(1, len(self.files)))
                 self.checkProgress.setVisible(len(self.files) > 1)
-                self.checkProgressLabel.setVisible(len(self.files) > 1)
                 QApplication.processEvents()
 
                 # now go through all the files
@@ -243,7 +240,6 @@ class SyntaxCheckerDialog(QDialog, Ui_SyntaxCheckerDialog):
         @param codestring optional sourcestring (str)
         """
         if self.syntaxCheckService is None or not self.files:
-            self.checkProgressLabel.setPath("")
             self.checkProgress.setMaximum(1)
             self.checkProgress.setValue(1)
             self.__finish()
@@ -251,7 +247,6 @@ class SyntaxCheckerDialog(QDialog, Ui_SyntaxCheckerDialog):
 
         self.filename = self.files.pop(0)
         self.checkProgress.setValue(self.progress)
-        self.checkProgressLabel.setPath(self.filename)
         QApplication.processEvents()
         self.__resort()
 
@@ -291,8 +286,6 @@ class SyntaxCheckerDialog(QDialog, Ui_SyntaxCheckerDialog):
         """
         self.__lastFileItem = None
 
-        self.checkProgressLabel.setPath(self.tr("Preparing files..."))
-
         argumentsList = []
         for progress, filename in enumerate(self.files, start=1):
             self.checkProgress.setValue(progress)
@@ -318,7 +311,6 @@ class SyntaxCheckerDialog(QDialog, Ui_SyntaxCheckerDialog):
 
         # reset the progress bar to the checked files
         self.checkProgress.setValue(self.progress)
-        self.checkProgressLabel.setPath(self.tr("Transferring data..."))
         QApplication.processEvents()
 
         self.__finished = False
@@ -328,7 +320,6 @@ class SyntaxCheckerDialog(QDialog, Ui_SyntaxCheckerDialog):
         """
         Private slot handling the completion of a batch job.
         """
-        self.checkProgressLabel.setPath("")
         self.checkProgress.setMaximum(1)
         self.checkProgress.setValue(1)
         self.__finish()
@@ -395,7 +386,6 @@ class SyntaxCheckerDialog(QDialog, Ui_SyntaxCheckerDialog):
 
         self.progress += 1
         self.checkProgress.setValue(self.progress)
-        self.checkProgressLabel.setPath(fn)
         if time.monotonic() - self.__timenow > 0.01:
             QApplication.processEvents()
             self.__timenow = time.monotonic()
@@ -435,7 +425,6 @@ class SyntaxCheckerDialog(QDialog, Ui_SyntaxCheckerDialog):
             self.resultList.header().setStretchLastSection(True)
 
             self.checkProgress.setVisible(False)
-            self.checkProgressLabel.setVisible(False)
 
     def on_buttonBox_clicked(self, button):
         """
