@@ -167,6 +167,6 @@ class ProjectFile(QObject):
                     projectDict["project"][key]
                 )
 
-        self.__project.pdata = projectDict["project"]
+        self.__project.pdata.update(projectDict["project"])
 
         return True
