@@ -8,6 +8,7 @@ Module implementing an outline widget for source code navigation of the editor.
 """
 
 import contextlib
+import functools
 
 from PyQt6.QtCore import pyqtSlot, Qt, QCoreApplication, QModelIndex, QPoint
 from PyQt6.QtWidgets import QTreeView, QAbstractItemView, QMenu, QApplication, QDialog
@@ -274,7 +275,6 @@ class EditorOutlineView(QTreeView):
             QCoreApplication.translate("EditorOutlineView", "Goto"), self
         )
         self.__gotoMenu.aboutToShow.connect(self.__showGotoMenu)
-        self.__gotoMenu.triggered.connect(self.__gotoAttribute)
 
         self.__attributeMenu = QMenu(self)
         self.__attributeMenu.addMenu(self.__gotoMenu)
@@ -403,6 +403,7 @@ class EditorOutlineView(QTreeView):
                 )
             )
             act.setData(lineno)
+            act.triggered.connect(functools.partial(self.__gotoAttribute, act))
 
     #######################################################################
     ## Context menu handlers below
