@@ -836,8 +836,7 @@ class Browser(QTreeView):
         """
         if filterList is None:
             filterList = self.selectedItemsFilter
-        categories = {}
-        categories["sum"] = 0
+        categories = {"sum": 0}
         for typ in filterList:
             categories[str(typ)] = 0
 
