@@ -69,16 +69,28 @@ class BackgroundService(QTcpServer):
         ## Note: Need the port if started external in debugger:
         print("Background Service listening on: {0:d}".format(port))
         # __IGNORE_WARNING__
+
+        interpreter = self.__getPythonInterpreter()
+        if interpreter:
+            process = self.__startExternalClient(interpreter, port)
+            if process:
+                self.processes["Python3"] = process, interpreter
+
+    def __getPythonInterpreter(self):
+        """
+        Private method to generate the path of the Python interpreter to be
+        used to run the background client.
+
+        @return path of the Python interpreter
+        @rtype str
+        """
         venvName = Preferences.getDebugger("Python3VirtualEnv")
         interpreter = (
             ericApp().getObject("VirtualEnvManager").getVirtualenvInterpreter(venvName)
         )
         if not interpreter:
             interpreter = Globals.getPythonExecutable()
-        if interpreter:
-            process = self.__startExternalClient(interpreter, port)
-            if process:
-                self.processes["Python3"] = process, interpreter
+        return interpreter
 
     def __startExternalClient(self, interpreter, port):
         """
@@ -265,6 +277,8 @@ class BackgroundService(QTcpServer):
                         self.__cancelled = True
                 else:
                     self.batchJobDone.emit(fx, lang)
+                    self.restartService(lang, forceKill=True)
+                    # TODO: monitor this change
             else:
                 callback = self.services.get((fx, lang))
                 if callback:
@@ -277,12 +291,7 @@ class BackgroundService(QTcpServer):
         """
         Public slot to restart the built in languages.
         """
-        venvName = Preferences.getDebugger("Python3VirtualEnv")
-        interpreter = (
-            ericApp().getObject("VirtualEnvManager").getVirtualenvInterpreter(venvName)
-        )
-        if not interpreter:
-            interpreter = Globals.getPythonExecutable()
+        interpreter = self.__getPythonInterpreter()
 
         # Tweak the processes list to reflect the changed interpreter
         proc, inter = self.processes.pop("Python3", [None, None])
